
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
API
APIs
AdWords
Alders
Alders'
Andy
AnonymousIP
BR
CN
Choroba
City
Client
ConnectionType
Continent
Country
Database
Dave
Domain
Eilam
Eilam's
Enterprise
Error
Flat
Florian
Fowler
GEOLOCATION
GEONAMES
Generic
GeoIP
GeoIP2
GeoLite
GeoNames
GitHub
Graham
Greg
HTTP
HasIPAddress
HasLocales
HasNames
HasSubdivisions
Hunter
IANA
IP
IP's
IPAddressNotFound
IPv
ISP
Inc
Insights
Jack
Knop
Location
Mark
Mateu
MaxMind
MaxMind's
Model
NA
OC
Oceania
Olaf
Omni
Oschwald
Oschwald's
Oxfordshire
Postal
Ragwitz
Reader
Record
RepresentedCountry
Role
Rolsky
Rolsky's
SSL
Subdivision
Tor
Traits
Type
Types
URI
VERSIONING
VPN
WebService
YYY
YYYZZZ
ZZZ
anonymizing
bin
choroba
com
contentDeliveryNetwork
de
dialup
docs
downloadable
drolsky
en
ergument
es
foo
fr
geoip
geolocation
geoname_id
github
goschwald
haarg
hostname
ip
ja
lib
libmaxminddb
lookup
maxmind
mfowler
mhunter
oalders
omni
params
pt
rafl
routable
ru
searchEngineSpider
sourced
synced
ua
uk
unpopulated
versioning
web
zh
